%define module numpy

Name:           python-%{module}
Version:        1.22.2
Release:        %mkrel 1
Summary:        A fast multidimensional array facility for Python

License:        BSD and Python
Group:          Development/Python
Url:            http://www.numpy.org
Source0:        %{module}-%{version}.tar.xz
Patch1:         numpy-linking.patch

BuildRequires:	%{_lib}blas-devel
BuildRequires:  %{_lib}cblas-devel

BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:  %{_lib}lapack-devel
BuildRequires:  libquadmath-devel

BuildRequires:  python3-cython
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools

%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.


%package -n python3-%{module}
Summary:        A fast multidimensional array facility for Python3
Group:		      Development/Python
License:        BSD

%description -n python3-%{module}
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-%{module}-devel
Summary:        Numpy headers
Group:		      Development/Python
Requires:       python3-%{module} = %{version}-%{release}
Requires:       python3-%{module}-f2py = %{version}-%{release}
Requires:       python3-devel
Provides:       python3-numeric-devel

%description -n python3-numpy-devel
This package contains header files need to develop modules
in C and Fortran that can interact with Numpy

%package -n python3-%{module}-f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       python3-numpy = %{version}-%{release}

%description -n python3-numpy-f2py
This package includes a version of f2py that works properly with NumPy.

%prep
%setup -qn %{module}-%{version}
%apply_patches

# force cythonize
rm -rf PKG-INFO

%build
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    FFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py build


%install
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    FFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py install --root %{buildroot}

# symlink for includes
mkdir -p %{buildroot}%{py3_incdir}
ln -s %{python3_sitearch}/%{module}/core/include/%{module} %{buildroot}%{py3_incdir}/%{module}

# Remove doc files that should be in %doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/LICENSE.txt

%files -n python3-%{module}
%doc THANKS.txt site.cfg.example LICENSE.txt
%{python3_sitearch}/*
%exclude %{python3_sitearch}/%{module}/core/include/
%exclude %{python3_sitearch}/%{module}/core/lib
%exclude %{python3_sitearch}/%{module}/f2py

%files -n python3-%{module}-f2py
%{_bindir}/f2py
%{_bindir}/f2py3
%{_bindir}/f2py%{python3_version}
%{python3_sitearch}/%{module}/f2py

%files -n python3-%{module}-devel
%{py3_incdir}/%{module}
%{python3_sitearch}/%{module}/core/include/
%{python3_sitearch}/%{module}/core/lib


%changelog
* Thu Feb 24 2022 TerryN <terryn94 at gmail.com>  1.22.2-1pclos2022
- update and rebuild for python 3.10

* Sun Apr 29 2018 marcin82 <fixxer1982 at gmail.com> 1.14.2-2pclos2018
- fix incorrect dependencies

* Tue Apr 10 2018 marcin82 <fixxer1982 at gmail.com> 1.14.2-1pclos2018
- update

* Fri Sep 22 2017 bb2 <bb2> - 1.13-2pclos2017
- rebuild

* Sat Sep 16 2017 bb2 <bb2> - 1.13-1pclos2017
- new version

* Thu Sep 14 2017 bb2 <bb2> - 1.11.2-1pclos2017
- new version
